@@ -7,6 +7,10 @@ from discord.http import Route
 from discord.utils import DISCORD_EPOCH
 
 
+# Lmfao look at this pro-gamer move
+Route.BASE = Route.BASE.replace("/v7", "/v8")
+
+
 __all__ = (
     'ResponseType',
     'InteractionDataOption',
@@ -680,11 +684,11 @@ class Option:
     
     def __repr__(self):
         desc = f"name={self.name} description={self.description} type={self.type}"
-        req = getattr(self, "required")
+        req = getattr(self, "required", None)
         if req is not None: desc = f"{desc} required={req}"
-        options = getattr(self, "options")
+        options = getattr(self, "options", None)
         if options is not None: desc = f"{desc} options={options}"
-        choices = getattr(self, "choices")
+        choices = getattr(self, "choices", None)
         if choices is not None: desc = f"{desc} choices={choices}"
         return f"<{_self_name(self)} {desc}>"
 
